@@ -38,7 +38,8 @@ tagging<- function(code, jiebar) {
     if(is.null(jiebar$output)){
       basenames <- gsub("\\.[^\\.]*$", "", code[1])
       extnames  <- gsub(basenames, "", code[1], fixed = TRUE)
-      output    <- paste(basenames, ".segment", as.numeric(Sys.time()), extnames, sep = "")
+      times_char = gsub(" |:","_",as.character(Sys.time()))
+      output    <- paste(basenames, ".segment.", times_char , extnames, sep = "")
     }  else {
       output<-jiebar$output
     }
@@ -173,10 +174,10 @@ tagl <- function(code, jiebar, symbol, lines, output, encoding, write_file,FILES
 
 tagw <- function(code, jiebar,  symbol, FILESMODE) {
   
-  if (symbol == F) {
-    code <- gsub("[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]", " ", code)
-  } 
-  #  code <- gsub("^\\s+|\\s+$", "", gsub("\\s+", " ", code))
+#   if (symbol == F) {
+#     code <- gsub("[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]", " ", code)
+#   } 
+#   #  code <- gsub("^\\s+|\\s+$", "", gsub("\\s+", " ", code))
   if(jiebar$bylines == FALSE){
     if(length(code) > 1){
       code <- paste(code, collapse = " ")
@@ -193,6 +194,9 @@ tagw <- function(code, jiebar,  symbol, FILESMODE) {
     if (.Platform$OS.type == "windows") {
       Encoding(result)<-"UTF-8"
     }
+    if (symbol == F) {
+      result <- grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", result, perl = TRUE,value = TRUE,invert = T)
+    }
   } else{
     
     length_of_input = length(code)
@@ -211,6 +215,9 @@ tagw <- function(code, jiebar,  symbol, FILESMODE) {
       if (.Platform$OS.type == "windows") {
         Encoding(tmp_result)<-"UTF-8"
       }
+      if (symbol == F) {
+        tmp_result <- grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", tmp_result, perl = TRUE,value = TRUE,invert = T)
+      }
       result[[num]] = tmp_result
     }
   }
